@@ -26,7 +26,15 @@
 #include "NetLibraryView.h"
 #include "../network/NetworkLink.h"
 
-ShowNetworkLibraryAction::ShowNetworkLibraryAction(FBReader &fbreader) : SetModeAction(fbreader, FBReader::NET_LIBRARY_MODE, FBReader::BOOK_TEXT_MODE) {
+#if MAEMO_VERSION==4
+// In Maemo5, we only show Net Library in the Book Collection view
+#define NET_LIBRARY_VISIBILITY_MODE FBReader::BOOK_COLLECTION_MODE
+#else
+// Normally, the Net Library is shown in the Book view
+#define NET_LIBRARY_VISIBILITY_MODE FBReader::BOOK_TEXT_MODE
+#endif
+
+ShowNetworkLibraryAction::ShowNetworkLibraryAction(FBReader &fbreader) : SetModeAction(fbreader, FBReader::NET_LIBRARY_MODE, NET_LIBRARY_VISIBILITY_MODE) {
 }
 
 bool ShowNetworkLibraryAction::isVisible() const {
